@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import List, Type, Tuple, Union
+from typing import Dict, List, Type, Tuple, Union
 from dataclasses import asdict, dataclass
 
 from blocks import Event
@@ -35,6 +35,10 @@ class Row(Event):
     def values(self) -> Tuple:
         return tuple(asdict(self).values())
 
+    @property
+    def as_dict(self) -> Dict:
+        return asdict(self)
+
 
 @dataclass
 class Table(Event):
@@ -105,3 +109,4 @@ class Query(Event):
     """
     text: str
     codec: Type[Union[Row, Table]]
+    partition_key: Union[str, None] = None
