@@ -12,6 +12,7 @@ from blocks.graph import Graph
 from blocks.types import Event, Source, Processor, AsyncSource, EventOrEvents, ParallelEvent, AsyncProcessor
 from blocks.logger import logger
 from blocks.types.base import is_named_tuple
+from blocks.metric_collector import MetricCollector, EventTime
 
 SyncProcessors = DefaultDict[Type[Event], List[Processor]]
 
@@ -32,12 +33,22 @@ class Runner(object):
     - proceeds actual shutdown of the app.
     """
 
-    def __init__(self, graph: Graph, terminal_event: Optional[Type[Event]]) -> None:
+    def __init__(
+        self,
+        graph: Graph,
+        terminal_event: Optional[Type[Event]],
+        collect_metric: bool = False,
+        *,
+        metric_time_interval: int = 60,
+    ) -> None:
         """
         Init runner instance.
 
-        :param graph:           Computational graph to execute.
-        :param terminal_event:  Special event which simply stops execution, when processed.
+        :param graph:                   Computational graph to execute.
+        :param terminal_event:          Special event which simply stops execution, when processed.
+        :param collect_metric:          Flag responsible for collecting metrics. If the flag is True,
+                                        the metrics will be collected
+        :param metric_time_interval:    Time interval for metric aggregation.
         """
         if graph.contains_async_blocks:
             raise RuntimeError('Blocks graph contains async blocks, must be run by AsyncRunner')
@@ -48,6 +59,13 @@ class Runner(object):
         self._alive = True
         self._pool: Optional[Pool] = Pool(graph.count_of_parallel_tasks) if graph.count_of_parallel_tasks > 0 else None
         self._terminal_event = terminal_event
+        self._collect_metric = collect_metric
+
+        if self._collect_metric:
+            self._run_processor = self._metric_run_proc
+            self._mp = MetricCollector(metric_time_interval=metric_time_interval)
+        else:
+            self._run_processor = self._run_proc
 
     def run(self, interval: float, once: bool) -> None:
         """
@@ -129,11 +147,20 @@ class Runner(object):
         ))
         logger.error(exc)
 
+    def _metric_run_proc(self, processor: Processor, input_event: Event) -> EventOrEvents:
+        with self._mp.timer as timer:
+            output_event = processor(input_event)
+        self._mp.collect(processor, EventTime(type(input_event), timer.start, timer.end))
+        return output_event
+
+    def _run_proc(self, processor: Processor, input_event: Event) -> EventOrEvents:
+        return processor(input_event)
+
     def _process_events(self, input_event: Event) -> None:
         for processor in self._processors[type(input_event)]:
             logger.debug('Processor: {0} event: {1}'.format(processor, input_event))
             try:
-                output_event = processor(input_event)
+                output_event = self._run_processor(processor, input_event)
             except:
                 self.stop()
                 logger.error('Execution failed during processing the event: {0}({1}) {2}'.format(
@@ -148,7 +175,7 @@ class Runner(object):
                         raise ValueError('Tried to process parallel event while should not be!')
                     self._pool.apply_async(
                         run_parallel_processor,
-                        (parallel_event.encode(), ),
+                        (parallel_event.encode(),),
                         callback=self._append_events,
                         error_callback=lambda exc: self._handle_pool_exceptions(exc, parallel_event)
                     )
@@ -160,6 +187,8 @@ class Runner(object):
         while self._q:
             event = self._q.popleft()
             self._process_events(event)
+            if self._collect_metric:
+                self._append_events(self._mp.get_aggregate_events())
 
 
 class AsyncRunner(object):
