@@ -6,11 +6,13 @@ import pytest
 
 @pytest.fixture(autouse=True)
 def run_around_tests() -> Generator[None, None, None]:
-    file_name = 'GRAPH.png'
-    if os.path.exists(file_name):
-        raise
+    files = ['GRAPH.png', 'DAG.svg']
+    for file_name in files:
+        if os.path.exists(file_name):
+            raise
     try:
         yield
     finally:
-        if os.path.exists(file_name):
-            os.remove(file_name)
+        for file_name in files:
+            if os.path.exists(file_name):
+                os.remove(file_name)
